@@ -1,5 +1,5 @@
 package Array::FIFO;
-$Array::FIFO::VERSION = '0.01';
+$Array::FIFO::VERSION = '0.02';
 use Moose;
 
 use namespace::autoclean;
@@ -11,7 +11,7 @@ Array::FIFO - Simple FIFO array, with a few convenience methods
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -103,7 +103,6 @@ L<http://www.perlfoundation.org/artistic_license_2_0>
 
 
 has max_size => ( is => 'rw', isa => 'Int', default => -1 );
-has size => ( is => 'rw', isa => 'Int', default => 0 );
 
 has queue => (
     is => 'rw',
@@ -112,7 +111,8 @@ has queue => (
     default => sub { [ ] },
     handles => {
         add => 'push',
-        remove => 'shift'
+        remove => 'shift',
+        size => 'count',
     },
     trigger => sub {
         my $self = shift;
@@ -124,19 +124,18 @@ has queue => (
             }
         }
 
-        $self->size( scalar @{ $self->queue } );
+        my $size = $self->size;
 
         my $sum = 0;
         foreach my $q (@{ $self->queue }) {
-            #if (($q =~ /^-?\d+$/) || ($q =~ /^-?\d+\.?\d*$/)) {
             if ($q =~ /^-?\d+\.?\d*$/) {
-                $sum += int($q);
+                $sum += $q;
             }
         }
 
         $self->sum( $sum );
         if ($sum > 0) {
-            $self->average( $sum / $self->size );
+            $self->average( $sum / $size );
         }
         else {
             $self->average(0);
@@ -144,6 +143,17 @@ has queue => (
     },
     );
 
+around add => sub {
+    my $orig = shift;
+    my $self = shift;
+
+    my $last = $self->{queue}[0];
+
+    $self->$orig( @_ );
+
+    $last;
+};
+
 has sum => ( is => 'rw', isa => 'Int' );
 has average => ( is => 'rw', isa => 'Num' );
 
